==> glpi_0.80.5.orig.tar.gz: glpi/ajax/sla.tabs.php <==
<?php
/*
 * @version $Id: sla.tabs.php 14684 2011-06-11 06:32:40Z remi $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2011 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");
header("Content-Type: text/html; charset=UTF-8");
header_nocache();

if (!isset($_POST["id"])) {
   exit();
}

if (empty($_POST["id"])) {
   $_POST["id"] = -1;
}

$sla      = new SLA();
$slalevel = new SlaLevel();

if ($_POST['id']>0 && $sla->getFromDB($_POST['id'])) {

   switch($_REQUEST['glpi_tab']) {
      case -1 :
         $slalevel->showForSLA($sla);
         $rule = new RuleTicket();
         $rule->showAndAddRuleForm($sla);
         Ticket::showListForItem('Sla', $_POST["id"]);
         Plugin::displayAction($sla, $_REQUEST['glpi_tab']);
         break;

      case 4:
         $rule = new RuleTicket();
         $rule->showAndAddRuleForm($sla);
         break;

      case 6:
         Ticket::showListForItem('Sla', $_POST["id"]);
         break;

      default :
         if (!Plugin::displayAction($sla, $_REQUEST['glpi_tab'])) {
            $slalevel->showForSLA($sla);
         }
   }
}

ajaxFooter();

?>

==> glpi_0.80.7.orig.tar.gz: glpi/ajax/sla.tabs.php <==
<?php
/*
 * @version $Id: sla.tabs.php 17154 2012-01-24 11:27:36Z moyo $
 -------------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2012 by the INDEPNET Development Team.

 http://indepnet.net/   http://glpi-project.org
 -------------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI. If not, see <http://www.gnu.org/licenses/>.
 --------------------------------------------------------------------------
 */

// ----------------------------------------------------------------------
// Original Author of file: Julien Dombre
// Purpose of file:
// ----------------------------------------------------------------------

define('GLPI_ROOT', '..');
include (GLPI_ROOT . "/inc/includes.php");
header("Content-Type: text/html; charset=UTF-8");
header_nocache();

if (!isset($_POST["id"])) {
   exit();
}

if (empty($_POST["id"])) {
   $_POST["id"] = -1;
}

$sla      = new SLA();
$slalevel = new SlaLevel();

if ($_POST['id']>0 && $sla->getFromDB($_POST['id'])) {

   switch($_REQUEST['glpi_tab']) {
      case -1 :
         $slalevel->showForSLA($sla);
         $rule = new RuleTicket();
         $rule->showAndAddRuleForm($sla);
         Ticket::showListForItem('SLA', $_POST["id"]);
         Plugin::displayAction($sla, $_REQUEST['glpi_tab']);
         break;

      case 4:
         $rule = new RuleTicket();
         $rule->showAndAddRuleForm($sla);
         break;

      case 6:
         Ticket::showListForItem('SLA', $_POST["id"]);
         break;

      default :
         if (!Plugin::displayAction($sla, $_REQUEST['glpi_tab'])) {
            $slalevel->showForSLA($sla);
         }
   }
}

ajaxFooter();

?>
